@@ -7,8 +7,8 @@
 
 Some private methods are here because I wanted to keep them with their tests.
 """
-import re
 import zipfile
+from pathlib import Path
 from typing import Optional
 
 from docx2python.docx_context import get_context, pull_image_files
@@ -16,10 +16,18 @@ from docx2python.docx_output import DocxContent
 from docx2python.docx_text import get_text
 
 
-def get_docx_content(
+def docx2python(
     docx_filename: str, image_folder: Optional[str] = None, html: bool = False
 ) -> DocxContent:
-    """Unzip a docx file and extract contents."""
+    """Unzip a docx file and extract contents.
+
+    There's a bit of ugly try/except toward the bottom.
+
+    One file in 5300 had the headers and footers mislabeled in
+    ``word/_rels.document.xml.rels``. Instead of ``header.xml``, this had the
+    header identified as ``word/header.xml``. After trying with
+    ``content_dir/file``, try again with just ``file``.
+    """
     zipf = zipfile.ZipFile(docx_filename)
     context = get_context(zipf)
     context["do_html"] = html
@@ -28,7 +36,13 @@ def get_docx_content(
         context["rId2Target"] = {
             x["Id"]: x["Target"] for x in context["content_path2rels"][filename_]
         }
-        return get_text(zipf.read(filename_), context)
+
+        try:
+            unzipped = zipf.read(filename_)
+        except KeyError:
+            # content dir specified twice
+            unzipped = zipf.read('/'.join(Path(filename_).parts[1:]))
+        return get_text(unzipped, context)
 
     header = [file_text(filename) for filename in context["headers"]]
     header = [x for y in header for x in y]
