@@ -10,11 +10,11 @@ import os
 import shutil
 import re
 
-from docx2python.main import get_docx_content
+from docx2python.main import docx2python
 from docx2python.iterators import iter_at_depth
 
-OUTPUT = get_docx_content("resources/example.docx")
-HTML_OUTPUT = get_docx_content("resources/example.docx", html=True)
+OUTPUT = docx2python("resources/example.docx")
+HTML_OUTPUT = docx2python("resources/example.docx", html=True)
 
 
 class TestFormatting:
@@ -157,7 +157,7 @@ class TestImageDir:
 
     def test_pull_image_files(self) -> None:
         """Copy image files to output path."""
-        get_docx_content("resources/example.docx", "delete_this/path/to/images")
+        docx2python("resources/example.docx", "delete_this/path/to/images")
         assert os.listdir("delete_this/path/to/images") == ["image1.png", "image2.jpg"]
         # clean up
         shutil.rmtree("delete_this")
